@@ -26,7 +26,7 @@
 #include "bookmarklistmodel.h"
 #include "bookmarkstool.h"
 // Okteta core
-#include <bookmark.h>
+#include <okteta/bookmark.h>
 // KF5
 #include <KLocalizedString>
 #include <KGuiItem>
