@@ -66,7 +66,7 @@ QString Utf32StringData::stringValue(int row) const
     uint val = mCodePoints.at(row);
     QString number = QString::number(val, 16).toUpper();
     if (number.length() == 1)
-        number = QStringLiteral("0") + number;
+        number = QLatin1Char('0') + number;
     if (val > UNICODE_MAX)
         return i18n("Value too big: 0x%1", number);
     else if (val > BMP_MAX) {
